# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import sorl.thumbnail.fields
import model_utils.fields
import froala_editor.fields
import luhublog.models.entry
import django.utils.timezone
from django.conf import settings
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        # ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('sites', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Author',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('name', models.CharField(default=b'', max_length=200, verbose_name=b'Nombre / seud\xc3\xb3nimo del autor', blank=True)),
                ('headline', models.CharField(default=b'', max_length=255, verbose_name=b'Corta descripci\xc3\xb3n', blank=True)),
                ('twitter', models.CharField(default=b'', help_text=b'@EsLuhu', max_length=50, verbose_name=b'Twitter', blank=True)),
                ('facebook_page_url', models.URLField(verbose_name=b'URL Pagina Facebook', blank=True)),
                ('twitter_url', models.URLField(verbose_name=b'URL Perfil Facebook', blank=True)),
                ('google_plus_url', models.URLField(verbose_name=b'URL Perfil Google Plus', blank=True)),
                ('is_active', models.BooleanField(default=True, verbose_name='is active')),
                ('user', models.OneToOneField(related_name='weblog_author', verbose_name=b'Perfil de usuario', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created'],
                'verbose_name': 'Autor',
                'verbose_name_plural': 'Autores',
            },
        ),
        migrations.CreateModel(
            name='Blog',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('title', models.CharField(max_length=60, verbose_name=b'Nombre del blog')),
                ('tag_line', models.CharField(max_length=140, verbose_name=b'Descripci\xc3\xb3n del blog')),
                ('entries_per_page', models.IntegerField(default=10, verbose_name=b'Entradas por pagina')),
                ('recents', models.IntegerField(default=5, verbose_name=b'Numero de entradas recientes a mostrar')),
                ('site', models.OneToOneField(verbose_name=b'Site', to='sites.Site')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BlogSocialMedia',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('facebook', models.URLField(verbose_name=b'Facebook URL', blank=True)),
                ('twitter', models.URLField(verbose_name=b'Twitter URL', blank=True)),
                ('google_plus', models.URLField(verbose_name=b'Google plus URL', blank=True)),
                ('instagram', models.URLField(verbose_name=b'Instagram URL', blank=True)),
                ('linkedin', models.URLField(verbose_name=b'Linkedin URL', blank=True)),
                ('youtube', models.URLField(verbose_name=b'YouTube URL', blank=True)),
                ('pinterest', models.URLField(verbose_name=b'Pinterest URL', blank=True)),
                ('blog', models.OneToOneField(related_name='social_media', verbose_name=b'Blog', to='luhublog.Blog')),
            ],
            options={
                'verbose_name': 'Redes sociales de los blogs',
            },
        ),
        migrations.CreateModel(
            name='Entry',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('title', models.CharField(max_length=100, verbose_name=b'title')),
                ('slug', models.SlugField(help_text=b"Used to build the entry's URL.", unique=True, verbose_name=b'slug')),
                ('lead_entry', models.CharField(max_length=255, verbose_name=b'Encabezado', blank=True)),
                ('image_header', sorl.thumbnail.fields.ImageField(upload_to=luhublog.models.entry.rename_filename, null=True, verbose_name=b'Imagen de encabezado', blank=True)),
                ('image_caption', sorl.thumbnail.fields.ImageField(upload_to=luhublog.models.entry.rename_filename, null=True, verbose_name=b'Imagen de la entrada', blank=True)),
                ('content', froala_editor.fields.FroalaField(verbose_name=b'Cuerpo de la entrada')),
                ('status', model_utils.fields.StatusField(default=b'DRAFT', max_length=100, no_check_for_status=True, choices=[(b'DRAFT', b'DRAFT'), (b'HIDDEN', b'HIDDEN'), (b'PUBLISHED', b'PUBLISHED')])),
                ('start_publication', models.DateTimeField(db_index=True, null=True, verbose_name=b'Fecha de publicaci\xc3\xb3n', blank=True)),
                ('seo_title', models.CharField(default=b'', help_text=b'Google typically displays the first 50-60 characters of a title tag', max_length=60, verbose_name=b'Meta Title', blank=True)),
                ('seo_description', models.CharField(default=b'', help_text=b'The description should optimally be between 10-155 characters', max_length=155, verbose_name=b'Meta Description', blank=True)),
                ('seo_keywords', models.CharField(default=b'', help_text=b'Opcional', max_length=400, verbose_name=b'Meta Keywords', blank=True)),
                ('author', models.ForeignKey(related_name='entries', verbose_name=b'Autor de la entrada', to='luhublog.Author')),
                ('blog', models.ForeignKey(blank=True, editable=False, to='luhublog.Blog', verbose_name=b'Site')),
            ],
            options={
                'ordering': ['-created'],
                'get_latest_by': '-start_publication',
                'verbose_name': 'Entrada',
                'verbose_name_plural': 'Entradas',
            },
        ),
        migrations.CreateModel(
            name='EntryCategory',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('name', models.CharField(max_length=60, verbose_name=b'Nombre')),
                ('slug', models.SlugField(verbose_name=b'ULR Slug')),
                ('description', models.CharField(max_length=255, verbose_name=b'Descripci\xc3\xb3n', blank=True)),
                ('image_cover', sorl.thumbnail.fields.ImageField(upload_to=luhublog.models.entry.rename_filename, null=True, verbose_name=b'Imagen de portada', blank=True)),
                ('blog', models.ForeignKey(blank=True, editable=False, to='luhublog.Blog', verbose_name=b'Site')),
                ('tags', taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text='A comma-separated list of tags.', verbose_name='Tags')),
            ],
            options={
                'verbose_name': 'Categor\xeda',
                'verbose_name_plural': 'Categor\xedas',
            },
        ),
        migrations.CreateModel(
            name='OpenGraph',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('og_type', models.CharField(default=b'blog', max_length=255, verbose_name='Resource type', choices=[(b'article', 'Article'), (b'website', 'Website'), (b'blog', 'Blog'), (b'book', 'Book'), (b'game', 'Game'), (b'movie', 'Movie'), (b'food', 'Food'), (b'city', 'City'), (b'country', 'Country'), (b'actor', 'Actor'), (b'author', 'Author'), (b'politician', 'Politician'), (b'company', 'Company'), (b'hotel', 'Hotel'), (b'restaurant', 'Restaurant')])),
                ('og_title', models.CharField(default=b'', help_text=b'titulo', max_length=255, verbose_name='Open Graph Title', blank=True)),
                ('og_description', models.CharField(default=b'', help_text=b'Facebook can display up to 300 characters, but I suggest treating anything above 200 as something extra.', max_length=300, verbose_name='Open Graph Description', blank=True)),
                ('og_app_id', models.CharField(default=b'', max_length=255, verbose_name='Facebook App ID', blank=True)),
                ('og_image', sorl.thumbnail.fields.ImageField(help_text=b'Imagen de 1200px por 630px', upload_to=b'seo/opengraph/', verbose_name=b'twitter:site')),
                ('object_id', models.PositiveIntegerField()),
                ('content_type', models.ForeignKey(to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'Social Metadata',
            },
        ),
        migrations.CreateModel(
            name='TwitterCard',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('site', models.CharField(help_text=b'@empresa', max_length=30, verbose_name=b'twitter:site')),
                ('creator', models.CharField(help_text=b'@autor', max_length=30, verbose_name=b'twitter:creator')),
                ('title', models.CharField(help_text=b'M\xc3\xa1ximo 70 caracteres', max_length=70, verbose_name=b'twitter:title')),
                ('description', models.CharField(help_text=b'M\xc3\xa1ximo 200 caracteres', max_length=200, verbose_name=b'twitter:description')),
                ('image', sorl.thumbnail.fields.ImageField(help_text=b'Imagen de 280px por 150px', upload_to=b'seo/twitter_cards/', verbose_name=b'twitter:site')),
                ('object_id', models.PositiveIntegerField()),
                ('content_type', models.ForeignKey(to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'Twitter Card',
            },
        ),
        migrations.AddField(
            model_name='entry',
            name='category',
            field=models.ForeignKey(verbose_name=b'Categor\xc3\xada', blank=True, to='luhublog.EntryCategory', null=True),
        ),
        migrations.AddField(
            model_name='entry',
            name='related',
            field=models.ManyToManyField(related_name='_related_+', verbose_name='related entries', to='luhublog.Entry', blank=True),
        ),
        migrations.AddField(
            model_name='entry',
            name='tags',
            field=taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text='A comma-separated list of tags.', verbose_name='Tags'),
        ),
        migrations.AlterIndexTogether(
            name='entry',
            index_together=set([('slug', 'created'), ('status', 'created', 'start_publication')]),
        ),
    ]



# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _

from model_utils.models import TimeStampedModel
from model_utils.managers import QueryManager

from luhublog.managers import entries_published


@python_2_unicode_compatible
class Author( TimeStampedModel ):

    user = models.OneToOneField(
                settings.AUTH_USER_MODEL,
                verbose_name='Perfil de usuario',
                related_name='weblog_author')

    name = models.CharField(
                verbose_name='Nombre / seudónimo del autor',
                max_length=200,
                blank=True,
                default="")

    headline = models.CharField(
                verbose_name='Corta descripción',
                max_length=255,
                blank=True,
                default="")

    twitter = models.CharField(
                verbose_name='Twitter',
                max_length=50,
                help_text='@EsLuhu',
                blank=True,
                default="")

    facebook_page_url = models.URLField(
                verbose_name='URL Pagina Facebook',
                blank=True)

    twitter_url = models.URLField(
                verbose_name='URL Perfil Twitter',
                blank=True)

    google_plus_url = models.URLField(
                verbose_name='URL Perfil Google Plus',
                blank=True)

    linkedin_plus_url = models.URLField(
                verbose_name='URL Perfil Linkedin',
                blank=True)


    is_active = models.BooleanField(
                _("is active"),
                default=True)

    objects = models.Manager()
    activated = QueryManager(is_active=True).order_by('-created')

    class Meta:
        """
        Author's meta informations.
        """
        ordering = ['-created',]
        verbose_name = 'Autor'
        verbose_name_plural = 'Autores'

    def __str__(self):
        """
        If the user has a full name, use it instead of the username.
        """
        if not self.name:
            name = self.user.get_full_name()
            if name == "":
                return self.user.email
            return name
        return self.name

    def save(self, *args, **kwargs):
        if self.twitter:
            if not self.twitter[0] == "@":
                self.twitter = "@"+self.twitter
        super(Author, self).save(*args, **kwargs)

    @property
    def full_name(self):
        if not self.name == "":
            return self.name
        return self.user.get_full_name()
            
    def entries_published(self):
        """
        Returns author's published entries.
        """
        return entries_published(self.entries)


from django.conf import settings

SEARCH_FIELDS = getattr(settings, 'BLOG_SEARCH_FIELDS',
                        ['title', 'lead', 'content',
                         'excerpt', 'image_caption', 'tags'])

TEST = "esto es un test"


# -*- coding: utf-8 -*-

from django.contrib.syndication.views import Feed
from django.core.urlresolvers import reverse, reverse_lazy

from models import Entry, Blog

BLOG = Blog.objects.get_blog()


class BlogFeed(Feed):
	title = getattr(BLOG, 'title', '')
	link = reverse_lazy('luhublog-list')
	description = getattr(BLOG, 'tag_line', '')

	def items(self):
		return Entry.objects.all()

	def item_description(self, item):
		return item.lead_entry

	def item_title(self, item):
		return item.title

	def item_pubdate(self,item):
		return item.start_publication

	def item_link(self, item):
		return reverse('lihublog-detail', kwargs={'slug' : item.slug})

	def item_author_name(self, item):
		return item.author.full_name


# -*- encoding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.core.exceptions import ValidationError
from django.contrib.sites.models import Site

from model_utils.models import TimeStampedModel

from sorl.thumbnail import ImageField

from imagekit.models import ImageSpecField
from imagekit.processors import ResizeToFill

from luhublog.models import Author, Blog, Entry

GPLUS_TYPE_CHOICES = (
	('Article', _('Article')),
	('Blog', _('Blog')),
	('Book', _('Book')),
	('Event', _('Event')),
	('LocalBusiness', _('LocalBusiness')),
	('Organization', _('Organization')),
	('Person', _('Person')),
	('Product', _('Product')),
	('Review', _('Review')),
)

#https://dev.twitter.com/cards/types
TWITTER_TYPE_CHOICES = (
	('summary', _('Summary')),
	('summary_large_image', _('Summary large image')),
)

class TwitterCard(TimeStampedModel):

	site = models.CharField(
			verbose_name='twitter:site',
			max_length=30,
			help_text='@empresa')

	creator = models.CharField(
			verbose_name='twitter:creator',
			max_length=30,
			help_text='@autor')

	title = models.CharField(
			verbose_name='twitter:title',
			max_length=70,
			help_text='Máximo 70 caracteres')

	description = models.CharField(
			verbose_name='twitter:description',
			max_length=200,
			help_text='Máximo 200 caracteres')

	image = ImageField(
			verbose_name='twitter:site',
			upload_to="seo/twitter_cards/",
			help_text='Imagen de 280px por 150px')

	image_thumbnail = ImageSpecField(
			source='image',
			processors=[ResizeToFill(280, 150)],
			format='JPEG',
			options={'quality': 70})

	content_type = models.ForeignKey(ContentType)
	object_id = models.PositiveIntegerField()
	content_object = GenericForeignKey('content_type', 'object_id')

	class Meta:
		verbose_name= 'Twitter Card'

	def clean(self, *args, **kwargs):
		if not self.site.startswith('@') or not self.creator.startswith('@'):
			raise ValidationError("twitter:site o twitter.author debe comenzar por @")
		super(TwitterCard, self).clean(*args, **kwargs)

	def get_image_url(self):
		site = Site.objects.get_current()
		return "http://%s%s" % (site.domain, self.image_thumbnail.url)

	
# http://ogp.me/#types
OG_TYPE_CHOICES = (
	('article', _('Article')),
	('website', _('Website')),
	('blog', _('Blog')),
	('book', _('Book')),
	('game', _('Game')),
	('movie', _('Movie')),
	('food', _('Food')),
	('city', _('City')),
	('country', _('Country')),
	('actor', _('Actor')),
	('author', _('Author')),
	('politician', _('Politician')),
	('company', _('Company')),
	('hotel', _('Hotel')),
	('restaurant', _('Restaurant')),
)

class OpenGraph(TimeStampedModel):
	
	og_type = models.CharField(
			verbose_name=_('Resource type'), 
			max_length=255, 
			choices=OG_TYPE_CHOICES,
			default="blog"
	)

	og_title = models.CharField(
			_('Open Graph Title'), 
			max_length=255, 
			default='', 
			blank=True,
			help_text='titulo'
	)

	og_description = models.CharField(
			_('Open Graph Description'), 
			max_length=300, 
			default='', 
			blank=True,
			help_text='Facebook can display up to 300 characters, but I suggest treating anything above 200 as something extra.'
	)

	og_app_id = models.CharField(
			_('Facebook App ID'), 
			max_length=255, 
			default='', 
			blank=True
	)

	og_image = ImageField(
			verbose_name='twitter:site',
			upload_to="seo/opengraph/",
			help_text='Imagen de 1200px por 630px')

	og_image_thumbnail = ImageSpecField(
			source='og_image',
			processors=[ResizeToFill(1200, 630)],
			format='JPEG',
			options={'quality': 70})

	content_type = models.ForeignKey(ContentType)
	object_id = models.PositiveIntegerField()
	content_object = GenericForeignKey('content_type', 'object_id')

	class Meta:
		verbose_name = "Social Metadata"

	def get_og_image_url(self):
		site = Site.objects.get_current()
		return "http://%s%s" % (site.domain, self.og_image_thumbnail.url)

	@property
	def og_site_name(self):
		blog = Blog.objects.get_blog()
		return blog.title
	







# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('luhublog', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='author',
            name='linkedin_plus_url',
            field=models.URLField(verbose_name=b'URL Perfil Linkedin', blank=True),
        ),
        migrations.AlterField(
            model_name='author',
            name='twitter_url',
            field=models.URLField(verbose_name=b'URL Perfil Twitter', blank=True),
        ),
    ]



# -*- coding: utf-8 -*-

from django import template
from django.contrib.contenttypes.models import ContentType

from classytags.core import Options
from classytags.arguments import Argument
from classytags.helpers import InclusionTag

from luhublog.models import TwitterCard


register = template.Library()

class TwitterCardTag(InclusionTag):
	name = "twitter_card"
	template = "luhublog/__twitter_card.html"

	def get_context(self, context):
		object = context.get('object', None)
		if object:
			try:
				content_type = ContentType.objects.get_for_model(object)
			except Exception, e:
				return ""
			else:

				try:
					twitter_card = TwitterCard.objects.get(content_type=content_type, object_id=object.id)
				except Exception, e:
					return ""
				else:
					return { 'twitter' : twitter_card }
		return ""

register.tag(TwitterCardTag)


from django.contrib import admin
from django.contrib.contenttypes.admin import GenericStackedInline

from models import Author, Entry, EntryCategory, Blog, TwitterCard, OpenGraph, BlogSocialMedia


class TwitterCardInline(GenericStackedInline):
	model = TwitterCard
	max_num = 1


class OpenGraphInline(GenericStackedInline):
	model = OpenGraph
	max_num = 1

class BlogSocialMediaInline(admin.StackedInline):
	model = BlogSocialMedia
	max_num = 1

@admin.register(Blog)
class BlogAdmin( admin.ModelAdmin ):
	list_display = ('title', 'site',)
	inlines = [TwitterCardInline, OpenGraphInline, BlogSocialMediaInline]

@admin.register(Author)
class AuthorAdmin( admin.ModelAdmin ):
	list_display = ('user', 'full_name')
	
@admin.register(EntryCategory)
class EntryCategoryAdmin( admin.ModelAdmin ):
	list_display = ('name', 'blog',)
	
@admin.register(Entry)
class EntryAdmin( admin.ModelAdmin ):
	list_display = ('title', 'author', 'category', 'blog', 'status', )
	inlines = [TwitterCardInline, OpenGraphInline,]
	prepopulated_fields = {'slug': ('title',), }
	fieldsets = (
		(None, {
			'fields' : ('status', 'category', 'author')
		}),
		('Entrada', {
			'fields' : ('title', 'lead_entry', 'image_header', 'image_caption', 'content', 'related')
		}),
		('SEO', {
			'fields' : ('slug', 'seo_title', 'seo_description', 'seo_keywords')
		})
	)

	def get_queryset(self, request):
		return self.model.default.all()


# -*- encoding: utf-8 -*-

from datetime import datetime, timedelta

from django.db import models
from django.conf import settings
from django.contrib.sites.models import Site
from django.core.urlresolvers import reverse

from model_utils.models import TimeStampedModel

class BlogManager(models.Manager):
	def get_blog(self):
		site = Site.objects.get_current()
		blog = self.filter(site=site)
		if len(blog) > 0:
			return blog[0]
		return None

class Blog(TimeStampedModel):

	title = models.CharField(
				verbose_name='Nombre del blog',
				max_length=60)
	tag_line = models.CharField(
				verbose_name='Descripción del blog',
				max_length=140)
	entries_per_page = models.IntegerField(
				verbose_name='Entradas por pagina',
				default=10)
	recents = models.IntegerField(
				verbose_name='Numero de entradas recientes a mostrar',
				default=5)

	site = models.OneToOneField(
				Site,
				verbose_name='Site')

	objects = BlogManager()

	def __unicode__(self):
		return self.title

	def save(self, *args, **kwargs):
		super(Blog, self).save(*args, **kwargs)

	def get_absolute_url(self):
		return reverse('luhublog-detail')

	@property
	def full_url(self):
		return "http://%s%s" % ( self.site.domain, self.get_absolute_url() )

	def get_recents_entries(self):
		return self.entry_set.all()[:blog.recents]


class BlogSocialMedia(TimeStampedModel):
	blog = models.OneToOneField(Blog, verbose_name='Blog', related_name='social_media')

	facebook = models.URLField(verbose_name='Facebook URL', blank=True) 
	twitter = models.URLField(verbose_name='Twitter URL', blank=True)
	google_plus = models.URLField(verbose_name='Google plus URL', blank=True)
	instagram = models.URLField(verbose_name='Instagram URL', blank=True)
	linkedin = models.URLField(verbose_name='Linkedin URL', blank=True)
	youtube = models.URLField(verbose_name='YouTube URL', blank=True)
	pinterest = models.URLField(verbose_name='Pinterest URL', blank=True)

	class Meta:
		verbose_name='Red social del blog'
		verbose_name='Redes sociales de los blogs'

	def get_username_twitter(self):
		if self.twitter:
			twitter_base = "twitter.com/"
			twitter_url = self.twitter
			if not twitter_url.find(twitter_base) == -1:
				username = twitter_url[ twitter_url.find(twitter_base) + len(twitter_base) : ]
				if username.endswith('/'):
					username = username[:len(username)-1]
					return username
				return username
			else:
				return None
		else:
			return None


	






from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

class BlogConfig(AppConfig):
    """
    Config for Zinnia application.
    """
    name = 'luhublog'
    label = 'luhublog'
    verbose_name = _('Blog')


from django.db import models
from django.utils import timezone
# from django.contrib.sites.models import Site

# def tags_published():
# 	"""
# 	Return the published tags.
# 	"""
# 	from tagging.models import Tag
# 	from zinnia.models.entry import Entry
# 	tags_entry_published = Tag.objects.usage_for_queryset(
# 		Entry.published.all())
# 	# Need to do that until the issue #44 of django-tagging is fixed
# 	return Tag.objects.filter(name__in=[t.name for t in tags_entry_published])


def entries_published(queryset):
	"""
	Return only the entries published.
	"""
	now = timezone.now()
	return queryset.filter(
		models.Q(start_publication__lte=now) |
		models.Q(start_publication=None), status='PUBLISHED')


class EntryPublishedManager(models.Manager):
	"""
	Manager to retrieve published entries.
	"""

	def get_queryset(self):
		"""
		Return published entries.
		"""
		return entries_published(
			super(EntryPublishedManager, self).get_queryset())

	# def on_site(self):
	# 	"""
	# 	Return entries published on current site.
	# 	"""
	# 	return super(EntryPublishedManager, self).get_queryset().filter(
	# 		sites=Site.objects.get_current())

	# def search(self, pattern):
	# 	"""
	# 	Top level search method on entries.
	# 	"""
	# 	try:
	# 		return self.advanced_search(pattern)
	# 	except:
	# 		return self.basic_search(pattern)

	# def advanced_search(self, pattern):
	# 	"""
	# 	Advanced search on entries.
	# 	"""
	# 	from zinnia.search import advanced_search
	# 	return advanced_search(pattern)

	# def basic_search(self, pattern):
	# 	"""
	# 	Basic search on entries.
	# 	"""
	# 	lookup = None
	# 	for pattern in pattern.split():
	# 		query_part = models.Q()
	# 		for field in SEARCH_FIELDS:
	# 			query_part |= models.Q(**{'%s__icontains' % field: pattern})
	# 		if lookup is None:
	# 			lookup = query_part
	# 		else:
	# 			lookup |= query_part

	# 	return self.get_queryset().filter(lookup)


# class EntryRelatedPublishedManager(models.Manager):
# 	"""
# 	Manager to retrieve objects associated with published entries.
# 	"""

# 	def get_queryset(self):
# 		"""
# 		Return a queryset containing published entries.
# 		"""
# 		now = timezone.now()
# 		return super(
# 			EntryRelatedPublishedManager, self).get_queryset().filter(
# 			models.Q(entries__start_publication__lte=now) |
# 			models.Q(entries__start_publication=None),
# 			models.Q(entries__end_publication__gt=now) |
# 			models.Q(entries__end_publication=None),
# 			entries__status=PUBLISHED,
# 			entries__sites=Site.objects.get_current()
# 			).distinct()


# -*- encoding: utf-8 -*-

import os
import bleach

from django.db import models
from django.db.models import Q
from django.utils import timezone
from django.utils.text import Truncator
from django.utils.html import strip_tags
from django.utils.html import linebreaks
from django.template.defaultfilters import slugify
from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible
from django.utils.text import Truncator
from django.templatetags.static import static
from django.conf import settings
from django.core.urlresolvers import reverse
from django.contrib.sites.models import Site

from froala_editor.fields import FroalaField

from sorl.thumbnail import ImageField
from sorl.thumbnail import get_thumbnail

from taggit.managers import TaggableManager

from bs4 import BeautifulSoup

from model_utils.models import TimeStampedModel
from model_utils import Choices
from model_utils.fields import StatusField

from luhublog.managers import entries_published, EntryPublishedManager
from luhublog.models import Blog, Author

def rename_filename(instance, filename):
	file_name, file_extension = os.path.splitext(filename)
	file_name = slugify(filename)
	file_name = file_name[:-(len(file_extension)-1)]
	folder = instance.__class__.__name__.lower()
	return "blog/%s/%s%s" % (folder, file_name, file_extension)


class EntryCategory( TimeStampedModel):

	blog = models.ForeignKey(
					Blog,
					verbose_name='Site',
					blank=True,
					editable=False)

	name = models.CharField(
					verbose_name='Nombre',
					max_length=60)
	slug = models.SlugField(
					verbose_name='ULR Slug')

	description = models.CharField(
					verbose_name='Descripción',
					max_length=255,
					blank=True)

	image_cover = ImageField(
					verbose_name='Imagen de portada',
					upload_to=rename_filename,
					blank=True,
					null=True)

	tags = TaggableManager(
					blank=True)

	class Meta:
		verbose_name = 'Categoría'
		verbose_name_plural = "Categorías"

	def __unicode__(self):
		return self.name

	def save(self, *args, **kwargs):
		if not self.id:
			self.blog = Blog.objects.get_blog()
		super(EntryCategory, self).save(*args, **kwargs)


class Entry( TimeStampedModel):

	blog = models.ForeignKey(
					Blog,
					verbose_name='Site',
					blank=True,
					editable=False)

	STATUS = Choices('DRAFT', 'HIDDEN', 'PUBLISHED')

	category = models.ForeignKey(
					EntryCategory,
					verbose_name='Categoría',
					blank=True,
					null=True)

	title = models.CharField(
					verbose_name='title', 
					max_length=100)

	slug = models.SlugField(
					verbose_name='slug', 
					unique=True,
					help_text="Used to build the entry's URL.")
	
	lead_entry = models.CharField(
					verbose_name='Encabezado',
					max_length=255,
					blank=True)

	image_header = ImageField(
					verbose_name='Imagen de encabezado',
					upload_to=rename_filename,
					blank=True,
					null=True)
	
	image_caption = ImageField(
					verbose_name='Imagen de la entrada',
					upload_to=rename_filename,
					blank=True,
					null=True)

	content = FroalaField(
					verbose_name='Cuerpo de la entrada')

	status = StatusField()

	author = models.ForeignKey(
					Author,
					verbose_name='Autor de la entrada',
					related_name='entries')

	start_publication = models.DateTimeField(
					verbose_name='Fecha de publicación',
					db_index=True, 
					blank=True, 
					null=True)

	related = models.ManyToManyField(
		'self',
		blank=True,
		verbose_name=_('related entries'))

	# SEO

	seo_title = models.CharField(
			verbose_name='Meta Title',
			max_length=60,
			blank=True,
			default="",
			help_text='Google typically displays the first 50-60 characters of a title tag'
	)

	seo_description = models.CharField(
			verbose_name='Meta Description',
			max_length=155, 
			default='', 
			blank=True,
			help_text='The description should optimally be between 10-155 characters'
	)

	seo_keywords = models.CharField(
			verbose_name='Meta Keywords',
			max_length=400, 
			default='', 
			blank=True,
			help_text='Opcional'
	)

	objects = EntryPublishedManager()
	default = models.Manager()

	tags = TaggableManager(
					blank=True)

	class Meta:
		"""
		Entry's meta informations.
		"""
		ordering = ['-created']
		get_latest_by = '-start_publication'
		verbose_name = _('Entrada')
		verbose_name_plural = _('Entradas')
		index_together = [['slug', 'created'],
						  ['status', 'created', 'start_publication']]

	@property
	def status_display(self):
		return self.STATUS[self.status]

	@property
	def publication_date(self):
		"""
		Return the publication date of the entry.
		"""
		return self.start_publication or self.created

	@property
	def is_actual(self):
		"""
		Checks if an entry is within his publication period.
		"""
		now = timezone.now()
		if self.start_publication and now < self.start_publication:
			return False
		return True

	@property
	def is_visible(self):
		"""
		Checks if an entry is visible and published.
		"""
		return self.is_actual and self.status == PUBLISHED

	@property
	def previous_entry(self):
		"""
		Returns the previous published entry if exists.
		"""
		return self.previous_next_entries[0]

	@property
	def next_entry(self):
		"""
		Returns the next published entry if exists.
		"""
		return self.previous_next_entries[1]

	@property
	def previous_next_entries(self):
		"""
		Returns and caches a tuple containing the next
		and previous published entries.
		Only available if the entry instance is published.
		"""
		previous_next = getattr(self, 'previous_next', None)

		if previous_next is None:
			if not self.is_visible:
				previous_next = (None, None)
				setattr(self, 'previous_next', previous_next)
				return previous_next

			entries = list(self.__class__.published.all())
			index = entries.index(self)
			try:
				previous = entries[index + 1]
			except IndexError:
				previous = None

			if index:
				next = entries[index - 1]
			else:
				next = None
			previous_next = (previous, next)
			setattr(self, 'previous_next', previous_next)
		return previous_next

	# @property
	# def short_url(self):
	#     """
	#     Returns the entry's short url.
	#     """
	#     return get_url_shortener()(self)

	@property
	def word_count(self):
		"""
		Counts the number of words used in the content.
		"""
		return len(strip_tags(self.content).split())

	@property
	def related_published(self):
		"""
		Returns only related entries published.
		"""
		return entries_published(self.related)

	@property
	def summary(self):
		short = bleach.clean(self.content, tags=bleach.ALLOWED_TAGS, strip=True)
		return Truncator(short).chars(200)

	def get_image_caption(self):
		if self.image_caption:
			return self.image_caption.url

		soup = BeautifulSoup(self.content, "html.parser")
		img = soup.img
		if img:
			url = img.attrs.get('src')
			return url
		return static( settings.BLOG_ENTRY_CAPTION_DEFAULT )

	def get_image_header(self):
		if self.image_header:
			return self.image_header.url
		return None

	def save(self, *args, **kwargs):

		if not self.id:
			self.blog = Blog.objects.get_blog()

		if self.status == "PUBLISHED" and not self.start_publication:
			self.start_publication = timezone.now()
		super(Entry, self).save(*args, **kwargs)

	# @models.permalink
	def get_absolute_url(self):
		return reverse('luhublog-detail', kwargs={ 'slug' : self.slug } )

	@property
	def full_url(self):
		return "http://%s%s" % (self.blog.site.domain, self.get_absolute_url() )
	

	def __str__(self):
		title = Truncator(self.title).chars(30)
		return '%s: %s' % (title, self.status_display)




import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.txt')).read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name = 'django-luhublog',
    version = "0.1.14",
    packages = ["luhublog"],
    include_package_data = True,
    license = "BSD License",
    description = "Blog app",
    long_description = README,
    url = "www.luhu.es",
    author = "John Sanchez",
    author_email = "johnsanchezc@luhu.es",
    classifiers = [
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License', # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires = [
        'Django>=1.7.7',
        'django-model-utils==2.3.1',
	    'django-bleach==0.3.0',
        'Pillow',
        'sorl-thumbnail==12.3',
        'beautifulsoup4',
        'django-froala-editor',
        'django-taggit',
        'django-classy-tags',
        'django-imagekit',
    ],
)



from django.views.generic import ListView, DetailView
from django.views.generic.edit import CreateView, UpdateView, DeleteView
from django.views.generic.edit import FormView
from django.core.urlresolvers import reverse_lazy
from django.conf import settings

from luhublog.models import Author, Entry

from . import app_settings

# class AuthorDetailView(ListView):
# 	model = Author
# 	template_name = "dash/blog/author/author_list.html"

class EntryListView(ListView):
	model = Entry
	context_object_name = "entries"
	template_name = "luhublog/entry_list.html"


class EntryDetailView(DetailView):
	model = Entry
	context_object_name = "entry"
	template_name = "luhublog/entry_detail.html"



from luhublog.models.blog import Blog, BlogSocialMedia
from luhublog.models.author import Author
from luhublog.models.entry import Entry, EntryCategory
from luhublog.models.seo import TwitterCard, OpenGraph

__all__ = [
			TwitterCard.__name__,
			OpenGraph.__name__,
           	Blog.__name__,
           	BlogSocialMedia.__name__,
			EntryCategory.__name__,
			Entry.__name__,
           	Author.__name__,]


# -*- coding: utf-8 -*-

from django import forms
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Fieldset, Button, Submit, HTML, Reset, Div
from crispy_forms.bootstrap import FormActions

from froala_editor.widgets import FroalaEditor

from luhublog.models import Author, Entry

class EntryForm(forms.ModelForm):
	content = forms.CharField(
					label="Contenido",
					required=True,
					widget=FroalaEditor(
						options={
							'height': '500',
							'fullPage': 'true',
							'trackScroll': 'true'
						}
					))

	class Meta:
		model = Entry
		fields = ['title', 'slug', 'image_caption', 'image_header', 'lead_entry', 'content', 'status', 'author', 'related' ]

	def __init__(self, *args, **kwargs):
		super(EntryForm, self).__init__(*args, **kwargs)
		self.fields['author'].queryset = Author.activated.all()

		self.helper = FormHelper()
		self.helper.layout = Layout(
			
			Div(
				'title',
				'slug',
				'lead_entry',
				'content',
				css_class="mrg-b-lg"

			),
			HTML("<h3><span>Imagenes</span></h3>"),
			Div(
				'image_caption',
				'image_header',
				css_class="mrg-b-lg"
			),
			HTML("<h3><span>Publicacion</span></h3>"),
			Div(
				'status',
				'author',
				'related',
				css_class="mrg-b-lg"
			),
			
			FormActions(
				Submit('save', _('Save'), css_class="btn-primary btn-lg"),
				css_class="text-center"
			)

		)


# -*- coding: utf-8 -*-

from django import template

from classytags.core import Options
from classytags.arguments import Argument
from classytags.helpers import InclusionTag

register = template.Library()

class EntrySeoTag(InclusionTag):
	name = "entry_meta_seo"
	template = "luhublog/__seo_entry_meta.html"

	def get_context(self, context):
		entry = context.get('entry', None)
		if entry:
			try:
				meta = entry.entryseo
			except Exception, e:
				return ""
			else:
				return { 'meta' : meta, 'entry' : entry }
		return ""

register.tag(EntrySeoTag)


from django.conf.urls import include, patterns, url

from . import views
from luhublog.feed import BlogFeed 

urlpatterns = patterns('',
	url(r'^$', views.EntryListView.as_view(), name='luhublog-list'),
	url(r'^feed/$', BlogFeed(), name='luhublog-feed' ),
	url(r'^(?P<slug>[\w-]+)/$', views.EntryDetailView.as_view(), name='luhublog-detail'),
)